/**
 * @file tuya_child_lock.h
 * @author panda (panzd@tuya.com)
 * @brief child lock component
 * @version
 *      v1.3 - 修改默认按键5次后，关闭童锁功能；去除多余封装；
 *      v1.4 - 重构 api，解耦 dp 和上报
 * @date 2020-02-03
 *
 * @copyright Copyright © HANGZHOU 2020 Tuya Inc. All rights reserved.
 *
 */
#ifndef _TUYA_CHILD_LOCK_H
#define _TUYA_CHILD_LOCK_H

#include "tuya_cloud_types.h"
#include "uni_time_queue.h"

#ifdef __cplusplus
extern "C" {
#endif

#ifdef __TUYA_CHILD_LOCK_GLOBALS
#define __TUYA_CHILD_LOCK_EXT
#else
#define __TUYA_CHILD_LOCK_EXT extern
#endif

/***********************************************************
*************************micro define***********************
***********************************************************/

/***********************************************************
*************************function define********************
***********************************************************/
/**
 * @brief 童锁功能初始化，默认童锁为关闭
 * @return { OPRT_OK 代表成功。如果是其他错误码，请参考 tuya_error_code.h }
 */
__TUYA_CHILD_LOCK_EXT \
OPERATE_RET tuya_child_lock_init(VOID);

/**
 * @brief 设置童锁状态
 * @param[in] lock_en 童锁设置状态，true-进行上锁，false-进行解锁
 */
__TUYA_CHILD_LOCK_EXT \
VOID tuya_child_lock_set_stat(IN BOOL_T lock_en);

/**
 * @brief 设备是否可操作，即童锁是否已被激活为解锁可控状态
 *        每次按键控制时，使用此接口，会记录按键次数，并判断是否达到可操作状态；
 * @return BOOL_T true:童锁未上锁或激活解锁，可进行控制； false:童锁已上锁，不可控制
 */
__TUYA_CHILD_LOCK_EXT \
BOOL_T tuya_child_lock_active_operate(VOID);

/**
 * @brief 获取童锁设置参数
 *
 * @param[out] lock_stat 童锁状态
 * @param[out] unlock_cnt 解锁次数
 * @param[out] clear_time 清除次数时间
 * @return { OPRT_OK 代表成功。如果是其他错误码，请参考 tuya_error_code.h }
 */
__TUYA_CHILD_LOCK_EXT \
VOID tuya_child_lock_get_para(INOUT BOOL_T *lock_stat, INOUT INT_T *unlock_cnt, INOUT INT_T *clear_time);

/**
 * @brief 设置清除按键次数时间，单位ms
 * @param[in] time 设置时间 5000-5s
 */
__TUYA_CHILD_LOCK_EXT \
VOID tuya_child_lock_set_clear_cnt_time(IN INT_T time_ms);

/**
 * @brief 设置童锁解锁按键次数
 *        注意：默认设置为4次，代表按下第4次，就解锁童锁功能
 * @param[in] cnt 次数
 */
__TUYA_CHILD_LOCK_EXT \
VOID tuya_child_lock_set_unlock_cnt(IN UINT_T cnt);

/***********************************************************
************************* function end *********************
***********************************************************/

#ifdef __cplusplus
}
#endif

#endif
