/**
 * @file tuya_cr_time.h
 * @brief 
 * @author Jon (zenggong@tuya.com)
 * @version 1.0
 * @date 2021-05-13
 * 
 * @copyright Copyright (c) tuya.inc 2021
 * 
 * @note 名词介绍
 * CR - 为 cycle amd rand 缩写
 * 
 * @par 修改日志:
 * <table>
 * <tr><th>Date       <th>Version <th>Author  <th>Description
 * <tr><td>2021-05-13 <td>1.0     <td>Jon     <td>创建规范定时 API
 * <tr><td>2021-05-13 <td>1.1     <td>Jon     <td>1. 删除全部删除接口
 * </table>
 */
#ifndef TUYA_CR_TIME_H
#define TUYA_CR_TIME_H

#include "tuya_cloud_types.h"
#include "dptm_basic.h"

#ifdef __cplusplus
    extern "C" {
#endif

#ifdef _TUYA_TIMER_GLOBAL
    #define _TUYA_TIMER_EXT 
#else
    #define _TUYA_TIMER_EXT extern
#endif


/***********************************************************
*************************micro define***********************
***********************************************************/
#define TUYA_CR_INVALID_TYPE        0xFF        // 定时类型非法值
#define TUYA_CR_TYPE_MAX            3           // 定时类型最大数
#define TUYA_CR_CH_NUM_MAX          7           // 硬件通道最大数

/**
 * @brief 定时类型
 */
typedef UCHAR_T TUYA_CR_TIME_TYPE_E;

#define TUYA_CR_TYPE_NOMAL_TIME   (0x01 << 0)   // 普通定时
#define TUYA_CR_TYPE_RAND_TIME    (0x01 << 1)   // 随机定时类型
#define TUYA_CR_TYPE_CYCLE_TIME   (0x01 << 2)   // 循环定时

/**
 * @brief 定时到达触发回调
 * @param [out] ch_num - 子通道号
 * @param [in] ch_state - 通道状态
 * @param [in] time_type - 定时类型
 */
typedef VOID (*TY_CR_TIMER_CB) (IN UCHAR_T ch_num, IN BOOL_T ch_state, IN TUYA_CR_TIME_TYPE_E time_type);

/**
 * @brief 随机定时组件初始化
 * @param  times_type - 使能定时能力
 * @param  ch_num - 总通道数
 * @param  proce_cb - 定时触发回调(禁止注册空接口)
 * @return OPERATE_RET 
 * @note times_type - 使能定时能力
 */
_TUYA_TIMER_EXT \
OPERATE_RET tuya_cr_time_init(UCHAR_T times_type,IN UCHAR_T ch_num, IN TY_CR_TIMER_CB proce_cb);

/**
 * @brief 获取time_type定时类型，定时数据
 * @param  time_type 定时类型
 * @param  time_date_str 返回定时数据字符串(使用后需 Free 操作)
 * @return OPERATE_RET - OPRT_OK - 成功
 *                     - 其他 - 错误
 */
_TUYA_TIMER_EXT \
OPERATE_RET tuya_cr_time_get_data(IN TUYA_CR_TIME_TYPE_E time_type, CHAR_T **time_date_str);

/**
 * @brief 解析接收定时数据
 * @param  time_type  定时类型
 * @param  pstr 定时数据
 * @return OPERATE_RET - OPRT_OK - 成功
 *                     - 其他 - 错误
 * @note time_type 仅支持单个定时类型数据解析
 */
_TUYA_TIMER_EXT \
OPERATE_RET tuya_cr_time_set(IN TUYA_CR_TIME_TYPE_E time_type, IN PCHAR_T time_data_str);

/**
 * @brief 涂鸦随机定时组件擦除指定 定时类型 数据
 * @param  time_type 定时类型
 * @return VOID 
 */
_TUYA_TIMER_EXT \
VOID tuya_cr_time_erase(IN UCHAR_T time_type);

#ifdef __cplusplus
}
#endif

#endif /*TUYA_TIMER_H*/


