/**
 * @file tuya_inch.h
 * @author panda (panzd@tuya.com)
 * @brief 点动功能组件
 * @version 1.0.0 qiuping.wang  20190515
 *          1.0.1 panda/dyb     20200926
 *          1.0.2 panda         20210317
 * @date 2021-03-17
 *
 * @copyright Copyright © HANGZHOU 2020 Tuya Inc. All rights reserved.
 *
 */
#ifndef _TUYA_INCH_H
#define _TUYA_INCH_H

#include "tuya_cloud_types.h"

#ifdef __cplusplus
    extern "C" {
#endif

#ifdef __TUYA_INCH_GLOBALS
    #define __TUYA_INCH_EXT
#else
    #define __TUYA_INCH_EXT extern
#endif

/***********************************************************
*************************micro define***********************
***********************************************************/

/**
 * @brief 定时到达触发回调
 * @param [out] ch_num - 子通道号
 * @param [in] ch_state - 通道状态
 */
typedef VOID (*TY_INCH_TIMER_CB) (IN UCHAR_T ch_num, IN BOOL_T ch_state);

/***********************************************************
*************************function define********************
***********************************************************/
/**
 * @brief 点动定时 通道状态通知
 * @param  ch_num 通道
 * @param  status 通道状态
 * @return VOID 
 */
__TUYA_INCH_EXT \
VOID tuya_inch_time_notify_ch_status(IN UCHAR_T ch_num,IN BOOL_T status);

/**
 * @brief 获取点动定时数据
 *
 * @param[in] time_date_str 加密数据
 * @return OPERATE_RET 
 */
__TUYA_INCH_EXT \
OPERATE_RET tuya_inch_time_get(IN CHAR_T **pstr);

/**
 * @brief 设置点动定时
 *
 * @param[in] time_data_str 点动原始数据
 */
__TUYA_INCH_EXT \
VOID tuya_inch_time_set(IN PCHAR_T time_data_str);

/**
 * @brief 点动功能初始化
 * @param[in] ch_num 点动数量，可以理解为插座的路数
 * @param[in] callback 点动定时到达回调
 * @return {OPRT_OK 代表成功。如果是其他错误码，请参考 tuya_error_code.h }
 */
__TUYA_INCH_EXT \
OPERATE_RET tuya_inch_time_init(IN UINT_T ch_num, TY_INCH_TIMER_CB proce_cb);

/**
 * @brief 清空保存在flash中的点动数据
 *
 */
__TUYA_INCH_EXT \
VOID tuya_inch_time_erase(VOID);

#ifdef __cplusplus
}
#endif

#endif
