/**
 * @file tuya_measure_com.h
 * @author dyb / panda (panzd@tuya.com)
 * @brief
 * @version 1.0
 * @date 2020-11-02
 *
 * @copyright Copyright © HANGZHOU 2020 Tuya Inc. All rights reserved.
 *
 */
#ifndef  __TY_MEASURE_H__
#define  __TY_MEASURE_H__

#include "tuya_cloud_types.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef  __TY_MEASURE_GLOBAL
#define __TY_MEASURE_EXT
#else
#define __TY_MEASURE_EXT extern
#endif

/**************define****************/
/* 220V 产测电压、电流、功率 */
#define V_DEF_220 2200
#define I_DEF_220 392
#define P_DEF_220 864

/* 120V 产测电压、电流、功率 */
#define V_DEF_120 1200
#define I_DEF_120 833
#define P_DEF_120 1000

/**************typedef****************/
/*计量芯片*/
typedef enum {
    DEV_BL0937 = 0,
    DEV_HLW8012,
    DEV_HLW8032,
    DEV_BL0942,
    EMU_V9801,
    DEV_END
} TY_DEV_MEASURE_CHIP;

/*校准参数v,i,p,e*/
typedef struct {
    UINT_T  v_ref;
    UINT_T  i_ref;
    UINT_T  p_ref;
    UINT_T  e_ref;
} GENERAL_COE_S;

/*计量产测信息*/
typedef struct {
    UCHAR_T prod_result; //产测结果
    VOID* prod_date_struct; //产测内容
} PROD_MEASURE_COE_S;

/*io配置信息,为防止和应用冲突,通过__IO_TYPE_CONFIG__区分*/
#ifndef __IO_TYPE_CONFIG__
#define __IO_TYPE_CONFIG__
typedef enum {
    IO_DRIVE_LEVEL_LOW_COM, // 低电平有效
    IO_DRIVE_LEVEL_HIGH_COM, // 高电平有效
    IO_DRIVE_LEVEL_NOT_EXIST_COM // 该IO不存在
} IO_DRIVE_TYPE_COM;

typedef struct {
    IO_DRIVE_TYPE_COM type; // 有效电平类型
    UCHAR_T pin; // 引脚号
} IO_CONFIG_COM;
#endif

/*app 注册参数*/
typedef struct {
    UCHAR_T         type;        // 计量类型    0：bl0937  1:hlw8012  2:hlw8032
    UCHAR_T         resval;      // 电阻规格    1\2 毫欧
    UCHAR_T         epin;        // 功率检测管脚
    UCHAR_T         ivpin;       // 电压、电流检测管脚
    IO_CONFIG_COM   ivcpin;      // 电压/电流切换管脚,电压采样时有效电平

    UCHAR_T         timer_no;    // 定时器选择
    UCHAR_T         uart_no;     // 串口选择

    UINT_T          v_ref;       // 校准电压规格    220V  110V
    UINT_T          i_ref;       // 校准电流规格
    UINT_T          p_ref;       // 校准功率规格

    BOOL_T          if_measure;  //是否带计量
} TY_DEV_MEASURE_PAPR_S;

/**************function statement****************/

/**
 * @name: tuya_dev_measure_start
 * @msg:  启动计量功能
 * @param flag：true 为校准模式  false:正常采集
 * @return {OPERATE_RET} OPRT_OK: 代表成功。如果是其他错误码，请参考 tuya_error_code.h
 */
__TY_MEASURE_EXT \
OPERATE_RET tuya_dev_measure_start(IN BOOL_T flag);

/**
 * @name: tuya_dev_measure_reg
 * @msg:  注册计量参数
 * @param {dev} 需要注册的计量参数
 * @return {OPERATE_RET} OPRT_OK: 代表成功。如果是其他错误码，请参考 tuya_error_code.h
 */
__TY_MEASURE_EXT \
OPERATE_RET tuya_dev_measure_reg(IN TY_DEV_MEASURE_PAPR_S dev);

/**
 * @name: tuya_get_measure_rms
 * @msg:  获取电压、电流、功率
 * @param[out] {vSrc}：电压
 * @param[out] {iSrc}：电流
 * @param[out] {pSrc}：功率
 * @return {VOID}
 */
__TY_MEASURE_EXT \
VOID tuya_get_measure_rms(OUT UINT_T *vSrc,OUT UINT_T *iSrc,IN UINT_T *pSrc);

/**
 * @name: tuya_get_emasure_energy
 * @msg:  获取电量增量
 * @param {out} {energy}:电量增加值
 * @return {VOID}
 */
__TY_MEASURE_EXT \
VOID tuya_get_emasure_energy(OUT UINT_T *energy);

/**
 * @name: tuya_get_measure_rslt
 * @msg:  产测结果是否正确
 * @param[in] VOID
 * @return{BOOL_T} {TRUE:正确 FASLE:错误}
 */
__TY_MEASURE_EXT \
BOOL_T tuya_get_measure_rslt(VOID);

/**
 * @name: tuya_get_calibration_para
 * @msg:  获取产测内容，一般是返回结果、电压电流功率电量系数
 * @param[in] VOID
 * @return{校准数据} ref: PROD_MEASURE_COE_S
 *          ->prod_result
 *          ->GENERAL_COE_S.v_ref
 *          ->GENERAL_COE_S.i_ref
 *          ->GENERAL_COE_S.p_ref
 *          ->GENERAL_COE_S.e_ref
 */
__TY_MEASURE_EXT \
PROD_MEASURE_COE_S* tuya_get_calibration_para(VOID);

/**
 * @name: tuya_clear_calibration_date
 * @msg:  清除校准结果数据
 * @param {in} VOID
 * @return {VOID}
 */
__TY_MEASURE_EXT \
VOID tuya_clear_calibration_date(VOID);


#ifdef __cplusplus
}
#endif /*__cplusplus*/


#endif /*__TY_MEASURE_H__*/